pub enum ControlCreatePacketStreamError {
DeviceError,
WrongDeviceType,
AlreadyPending,
InvalidElementId,
InvalidOptions,
InvalidFormat,
InvalidPacketStream,
AlreadyAllocated,
FormatMismatch,
BadPacketStreamOption,
Other,
// some variants omitted
}Expand description
Errors returned by Control/CreatePacketStream.
Variants
DeviceError
This device has encountered an error and can no longer be controlled.
WrongDeviceType
This device type does not support the method that was called.
AlreadyPending
The previous CreatePacketStream call has not yet completed.
InvalidElementId
The required element_id is missing or does not refer to a PACKET_STREAM element.
InvalidOptions
The required options is missing.
InvalidFormat
The required options.format is missing.
InvalidPacketStream
The required packet_stream_server is missing.
AlreadyAllocated
An active PacketStream instance already exists for this Control.
FormatMismatch
The device does not support the specified format.
BadPacketStreamOption
The device cannot create a packet stream with the specified options.
Other
The driver returned some other error. This call may be retried.
Implementations
Sourceimpl ControlCreatePacketStreamError
impl ControlCreatePacketStreamError
pub fn from_primitive(prim: u32) -> Option<ControlCreatePacketStreamError>
pub fn from_primitive_allow_unknown(prim: u32) -> ControlCreatePacketStreamError
pub fn unknown() -> ControlCreatePacketStreamError
pub const fn into_primitive(self) -> u32
pub fn is_unknown(&self) -> bool