pub enum PacketStreamSetBufferError {
DeviceError,
AlreadyStarted,
AlreadyConfigured,
BadStrategy,
BadVmoConfig,
WrongDeviceType,
InvalidElementId,
InsufficientRights,
BufferTooSmall,
Other,
// some variants omitted
}Expand description
Errors returned by PacketStream/SetBuffer.
Variants
DeviceError
This device has encountered an error and can no longer be controlled.
AlreadyStarted
SetBuffers was called on a packet stream that is already started.
AlreadyConfigured
SetBuffers was called on a packet stream that already has buffers configured.
BadStrategy
The provided buffer type is not supported by this device.
BadVmoConfig
The VMO information provided for setup is invalid or incompatible.
WrongDeviceType
This device type does not support the method that was called.
InvalidElementId
The required element_id is missing or does not refer to a PACKET_STREAM element.
InsufficientRights
A shared memory buffer does not have the required rights.
BufferTooSmall
A shared memory buffer is too small for its associated stream.
Other
The driver returned some other error. This call may be retried.
Implementations
Sourceimpl PacketStreamSetBufferError
impl PacketStreamSetBufferError
pub fn from_primitive(prim: u32) -> Option<PacketStreamSetBufferError>
pub fn from_primitive_allow_unknown(prim: u32) -> PacketStreamSetBufferError
pub fn unknown() -> PacketStreamSetBufferError
pub const fn into_primitive(self) -> u32
pub fn is_unknown(&self) -> bool