pub enum PacketStreamStopError {
DeviceError,
AlreadyPending,
AlreadyStopped,
// some variants omitted
}Expand description
Errors returned by PacketStream/Stop.
Variants
DeviceError
This device has encountered an error and can no longer be controlled.
AlreadyPending
The previous Stop call has not yet completed.
AlreadyStopped
Stop was called on a packet stream that is already stopped.
Implementations
Sourceimpl PacketStreamStopError
impl PacketStreamStopError
pub fn from_primitive(prim: u32) -> Option<PacketStreamStopError>
pub fn from_primitive_allow_unknown(prim: u32) -> PacketStreamStopError
pub fn unknown() -> PacketStreamStopError
pub const fn into_primitive(self) -> u32
pub fn is_unknown(&self) -> bool