pub struct PacketStreamMarker;Trait Implementations
Sourceimpl Clone for PacketStreamMarker
impl Clone for PacketStreamMarker
Sourcefn clone(&self) -> PacketStreamMarker
fn clone(&self) -> PacketStreamMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PacketStreamMarker
impl Debug for PacketStreamMarker
Sourceimpl Hash for PacketStreamMarker
impl Hash for PacketStreamMarker
Sourceimpl Ord for PacketStreamMarker
impl Ord for PacketStreamMarker
Sourcefn cmp(&self, other: &PacketStreamMarker) -> Ordering
fn cmp(&self, other: &PacketStreamMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PacketStreamMarker
impl PartialEq for PacketStreamMarker
Sourceimpl PartialOrd for PacketStreamMarker
impl PartialOrd for PacketStreamMarker
Sourceimpl ProtocolMarker for PacketStreamMarker
impl ProtocolMarker for PacketStreamMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) PacketStream"
const DEBUG_NAME: &'static str = "(anonymous) PacketStream"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = PacketStreamProxy
type Proxy = PacketStreamProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = PacketStreamRequestStream
type RequestStream = PacketStreamRequestStream
The type of the stream of requests coming into a server.
impl Copy for PacketStreamMarker
impl Eq for PacketStreamMarker
impl StructuralPartialEq for PacketStreamMarker