pub struct PacketStreamProperties {
pub data_sink: Option<ClientEnd<PacketStreamSinkMarker>>,
pub format: Option<PacketStreamFormat>,
pub valid_bits_per_sample: Option<u8>,
pub supported_buffer_types: Option<BufferType>,
/* private fields */
}Expand description
Information about the associated audio stream.
Fields
data_sink: Option<ClientEnd<PacketStreamSinkMarker>>The channel used to transmit audio data packets.
Required.
format: Option<PacketStreamFormat>The negotiated format of the audio data in the buffer.
Required.
valid_bits_per_sample: Option<u8>The number of valid bits per sample.
Required, if format.pcm_format is set.
supported_buffer_types: Option<BufferType>The memory ownership models supported by the driver for this stream.
Required.