pub struct PacketStreamSetBuffersResponse {
pub packet_stream: Option<PacketStreamBuffers>,
/* private fields */
}Fields
packet_stream: Option<PacketStreamBuffers>An object that contains shared memory buffers required to transfer audio data.
Note: The client must ensure proper cache coherency for the VMOs contained within this struct. Memory ranges must be cache-invalidated before reads (for capture) and cache-flushed after writes (for playback) if the properties indicate a non-coherent domain.