pub struct PacketStreamStartRequest { /* private fields */ }Trait Implementations
Sourceimpl Clone for PacketStreamStartRequest
impl Clone for PacketStreamStartRequest
Sourcefn clone(&self) -> PacketStreamStartRequest
fn clone(&self) -> PacketStreamStartRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PacketStreamStartRequest
impl Debug for PacketStreamStartRequest
Sourceimpl<D> Decode<PacketStreamStartRequest, D> for PacketStreamStartRequestwhere
D: ResourceDialect,
impl<D> Decode<PacketStreamStartRequest, D> for PacketStreamStartRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> PacketStreamStartRequest
fn new_empty() -> PacketStreamStartRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for PacketStreamStartRequest
impl Default for PacketStreamStartRequest
Sourcefn default() -> PacketStreamStartRequest
fn default() -> PacketStreamStartRequest
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<PacketStreamStartRequest, D> for &PacketStreamStartRequestwhere
D: ResourceDialect,
impl<D> Encode<PacketStreamStartRequest, D> for &PacketStreamStartRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for PacketStreamStartRequest
impl PartialEq for PacketStreamStartRequest
Sourceimpl TypeMarker for PacketStreamStartRequest
impl TypeMarker for PacketStreamStartRequest
Sourcetype Owned = PacketStreamStartRequest
type Owned = PacketStreamStartRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for PacketStreamStartRequest
impl ValueTypeMarker for PacketStreamStartRequest
Sourcetype Borrowed<'a> = &'a PacketStreamStartRequest
type Borrowed<'a> = &'a PacketStreamStartRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<PacketStreamStartRequest as TypeMarker>::Owned,
) -> <PacketStreamStartRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<PacketStreamStartRequest as TypeMarker>::Owned, ) -> <PacketStreamStartRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for PacketStreamStartRequest
impl StructuralPartialEq for PacketStreamStartRequest