pub struct PacketStreamStopRequest { /* private fields */ }Trait Implementations
Sourceimpl Clone for PacketStreamStopRequest
impl Clone for PacketStreamStopRequest
Sourcefn clone(&self) -> PacketStreamStopRequest
fn clone(&self) -> PacketStreamStopRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PacketStreamStopRequest
impl Debug for PacketStreamStopRequest
Sourceimpl<D> Decode<PacketStreamStopRequest, D> for PacketStreamStopRequestwhere
D: ResourceDialect,
impl<D> Decode<PacketStreamStopRequest, D> for PacketStreamStopRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> PacketStreamStopRequest
fn new_empty() -> PacketStreamStopRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for PacketStreamStopRequest
impl Default for PacketStreamStopRequest
Sourcefn default() -> PacketStreamStopRequest
fn default() -> PacketStreamStopRequest
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<PacketStreamStopRequest, D> for &PacketStreamStopRequestwhere
D: ResourceDialect,
impl<D> Encode<PacketStreamStopRequest, D> for &PacketStreamStopRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for PacketStreamStopRequest
impl PartialEq for PacketStreamStopRequest
Sourceimpl TypeMarker for PacketStreamStopRequest
impl TypeMarker for PacketStreamStopRequest
Sourcetype Owned = PacketStreamStopRequest
type Owned = PacketStreamStopRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for PacketStreamStopRequest
impl ValueTypeMarker for PacketStreamStopRequest
Sourcetype Borrowed<'a> = &'a PacketStreamStopRequest
type Borrowed<'a> = &'a PacketStreamStopRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<PacketStreamStopRequest as TypeMarker>::Owned,
) -> <PacketStreamStopRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<PacketStreamStopRequest as TypeMarker>::Owned, ) -> <PacketStreamStopRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for PacketStreamStopRequest
impl StructuralPartialEq for PacketStreamStopRequest