pub struct PacketStreamStopResponse { /* private fields */ }Trait Implementations
Sourceimpl Clone for PacketStreamStopResponse
impl Clone for PacketStreamStopResponse
Sourcefn clone(&self) -> PacketStreamStopResponse
fn clone(&self) -> PacketStreamStopResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PacketStreamStopResponse
impl Debug for PacketStreamStopResponse
Sourceimpl<D> Decode<PacketStreamStopResponse, D> for PacketStreamStopResponsewhere
D: ResourceDialect,
impl<D> Decode<PacketStreamStopResponse, D> for PacketStreamStopResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> PacketStreamStopResponse
fn new_empty() -> PacketStreamStopResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for PacketStreamStopResponse
impl Default for PacketStreamStopResponse
Sourcefn default() -> PacketStreamStopResponse
fn default() -> PacketStreamStopResponse
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<PacketStreamStopResponse, D> for &PacketStreamStopResponsewhere
D: ResourceDialect,
impl<D> Encode<PacketStreamStopResponse, D> for &PacketStreamStopResponsewhere
D: ResourceDialect,
Sourceimpl PartialEq for PacketStreamStopResponse
impl PartialEq for PacketStreamStopResponse
Sourceimpl TypeMarker for PacketStreamStopResponse
impl TypeMarker for PacketStreamStopResponse
Sourcetype Owned = PacketStreamStopResponse
type Owned = PacketStreamStopResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for PacketStreamStopResponse
impl ValueTypeMarker for PacketStreamStopResponse
Sourcetype Borrowed<'a> = &'a PacketStreamStopResponse
type Borrowed<'a> = &'a PacketStreamStopResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<PacketStreamStopResponse as TypeMarker>::Owned,
) -> <PacketStreamStopResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<PacketStreamStopResponse as TypeMarker>::Owned, ) -> <PacketStreamStopResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for PacketStreamStopResponse
impl StructuralPartialEq for PacketStreamStopResponse